@@ -108,27 +108,18 @@ calc_dcatConjugacyContributions <- nimbleFunction(
 )
 
 ## used in conjugacy definition for dmnorm, to calculate 'contribution' terms;
-## avoids unnecessary matrix multiplications, when 'coeff' is identity matrix
+## formerly avoided unnecessary matrix multiplications, when 'coeff' is identity matrix by numerical computation
+## now we do via code processing to determine the realized link
 calc_dmnormConjugacyContributions <- nimbleFunction(
     name = 'calc_dmnormConjugacyContributions',
-    run = function(coeff = double(2), prec = double(2), vec = double(1), order = double()) {
-        if(dim(coeff)[1] == dim(coeff)[2]) {
-            d <- dim(coeff)[1]
-            total <- 0
-            for(i in 1:d) {
-                for(j in 1:d) {
-                    if(i == j) { total <- total + abs(coeff[i,j] - 1)
-                             } else     { total <- total + abs(coeff[i,j])     }
-                }
-            }
-            if(total < d * 1E-15) {
-                if(order == 1) ans <- prec %*% asCol(vec)
-                if(order == 2) ans <- prec
-                return(ans)
-            }
+    run = function(coeff = double(2), prec = double(2), vec = double(1), order = double(), use_coeff = double()) {
+        if(use_coeff == 0) {  ## identity, additive
+            if(order == 1) ans <- prec %*% asCol(vec)
+            if(order == 2) ans <- prec
+        } else {
+            if(order == 1) ans <- t(coeff) %*% (prec %*% asCol(vec))
+            if(order == 2) ans <- t(coeff) %*% prec %*% coeff
         }
-        if(order == 1) ans <- t(coeff) %*% (prec %*% asCol(vec))
-        if(order == 2) ans <- t(coeff) %*% prec %*% coeff
         return(ans)
         returnType(double(2))
     }
